@@ -1,11 +1,11 @@
-/* (C) 2003 - 2005 by Marcin Wiacek www.mwiacek.com */
+/* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
 #include <stdio.h>
 
 #include "../cfg/config.h"
 #include "gsmstate.h"
 #include "misc/coding/coding.h"
-#include "misc/ini.h"
+#include "misc/files.h"
 
 #ifdef WIN32
 #  include "device/serial/ser_w32.h"
@@ -184,43 +184,50 @@ void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 	if (value != NULL) sprintf(CFG->RSSLevel,"%s",UnicodeToStringReturn(value));
 }
 
+/**
+ * method for saving configuration file for HDD
+ */
 void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
 {
-	GSM_File	File;
+	INI_File	File;
+	wchar_t		x[200], x2[200];
 	BOOLEAN		read = FALSE;
-	GSM_Error	error;
-	char		buff[200];
-//	char		*sec;
 #ifndef WIN32
 	char		tmp[500];
 #endif
 
-	error.Code = GSM_ERR_UNKNOWN;
-
-	if (error.Code == GSM_ERR_UNKNOWN) error = File.ReadFromDisk(StringToUnicodeReturn("gammurc"));
+	if (read==FALSE && File.ReadFile("gammurc")==TRUE) read = TRUE;
 #ifndef WIN32
 	strcpy(tmp,getenv("HOME"));
 	strcat(tmp,"/.gammurc");
-	if (error.Code == GSM_ERR_UNKNOWN) error = File.ReadFromDisk(StringToUnicodeReturn(tmp));
-	if (error.Code == GSM_ERR_UNKNOWN) error = File.ReadFromDisk(StringToUnicodeReturn("/etc/gammurc"));
+	if (read==FALSE && File.ReadFile(tmp)==TRUE) read = TRUE;
+	if (read==FALSE && File.ReadFile("/etc/gammurc")==TRUE) read = TRUE;
 #endif
-//	if (error.Code == GSM_ERR_NONE) {
-//	} else {
-		File.Buffer.clear();
-		sprintf(buff,"[gammu]\n");
-		File.Buffer.append((unsigned char *)buff,strlen(buff));
-		sprintf(buff,"port = %s\n",CFG->Device);
-		File.Buffer.append((unsigned char *)buff,strlen(buff));
-		sprintf(buff,"connection = %s\n",CFG->Protocol);
-		File.Buffer.append((unsigned char *)buff,strlen(buff));
-		sprintf(buff,"model = %s\n",CFG->Phone);
-		File.Buffer.append((unsigned char *)buff,strlen(buff));
-		sprintf(buff,"compatibility = %s\n",CFG->Compatibility);
-		File.Buffer.append((unsigned char *)buff,strlen(buff));
+
+	StringToUnicode("gammu",x);
+
+	StringToUnicode("port",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Device));
+
+	StringToUnicode("connection",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Protocol));
+
+	StringToUnicode("model",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Phone));
+
+	StringToUnicode("compatibility",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Compatibility));
+
+	if (read) {
+		File.SaveToDisk(UnicodeToStringReturn(File.Info.ID.data()));
+	} else {
 		File.SaveToDisk("gammurc");
-//	}
+	}
 }
 
+/**
+ * method for setting handler, which can handle all frames returned from phones
+ */
 void GSM_StateMachine::SetUserReply(GSM_Error(*UsrReply)(int MsgLength, unsigned char MsgType, unsigned char *MsgBuffer, void *Struct, int RequestID))
 {
         if (Phones->Current != NULL) Phones->Current->SetUserReply(UsrReply);
