@@ -4,7 +4,7 @@
 #define gsm_state_h
 
 #include "misc/misc.h"
-#include "misc/ini.h"
+#include "misc/files.h"
 #include "device/gsmdev.h"
 #include "phone/gsmphone.h"
 #include "protocol/gsmprot.h"
@@ -18,6 +18,9 @@ typedef struct {
 	char		RSSLevel[200];
 } GSM_GPlusConfig;
 
+/**
+ * main class for managing phone
+ */
 class GSM_StateMachine
 {
 public:
