@@ -5,19 +5,74 @@
 #include "../../../misc/coding/coding.h"
 #include "../ndct34.h"
 
+// -------------------------------- shared ------------------------------------
+
 GSM_Error GSM_Phone_N6510::GetNextCalendar(GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max)
 {
 	if ((*Phones)->Feature("cal62")==TRUE) {
 		return DCT34->GetNextCalendar1(Entry,start,Current,Max);
 	} else {
-		return GetNextCalendar3(Entry,start,Current,Max);
+		return GetNextCalendar3NoteToDo2(Entry,start,Current,Max,&Entry->Location,0x00,ID_GetCalendar);
 	}
 }
 
-GSM_Error GSM_Phone_N6510::ReplyGetCalendarInfo3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+GSM_Error GSM_Phone_N6510::AddCalendar(GSM_CalendarEntry *Entry)
+{
+	if ((*Phones)->Feature("cal62")==TRUE) {
+		return DCT34->AddCalendar1(Entry);
+	} else {
+		return AddCalendar3(Entry);
+	}
+
+//      return AddCalendar3(Entry);
+//      return DCT34->AddCalendar2(Entry);
+//      return DCT34->AddCalendar1(Entry);
+}
+
+GSM_Error GSM_Phone_N6510::DeleteCalendar(GSM_CalendarEntry *Entry)
+{
+	return DCT34->DeleteCalendar(Entry);
+}
+
+GSM_Error GSM_Phone_N6510::GetNextNote(GSM_NoteEntry *Entry, BOOLEAN start, int *Current, int *Max)
+{
+	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x02, ID_GetNote);
+}
+
+GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
+{
+	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+
+	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x01, ID_GetToDo);
+}
+
+GSM_Error GSM_Phone_N6510::AddToDo(GSM_ToDoEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone_N6510::DeleteToDo(GSM_ToDoEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+// -------------------------------- method 3 ----------------------------------
+
+
+GSM_Error GSM_Phone_N6510::ReplyGetCalendarNoteToDoInfo3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
 	GSM_Cal_Loc     *CalendarLocations = (GSM_Cal_Loc *)S;
-	int	     i;
+	int	     	i;
 
 	(*Debug)->Deb("RECEIVED: calendar entries info method 3\n");
 
@@ -38,14 +93,16 @@ GSM_Error GSM_Phone_N6510::ReplyGetCalendarInfo3(GSM_Protocol_Message *msg, Debu
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::GetCalendarInfo3()
+GSM_Error GSM_Phone_N6510::GetCalendar3NoteToDo2Info(unsigned char type)
 {
 	GSM_Error       error;
 	unsigned char   Buff[] = {
 		NOKIA_FRAME1, 0x9E, 0xFF, 0xFF, 0x00, 0x00,
-		0x00, 0x00,	     // first location number
+		0x00, 0x00,	  // first location number
 		0x00};		  // 0 = calendar, 1 = ToDo in 6610 style, 2 = Notes
 
+	Buff[10] = type;
+
 	CalendarLocations.Locations.clear();
 	CalendarLocations.Length = 0;
 
@@ -70,18 +127,126 @@ GSM_Error GSM_Phone_N6510::GetCalendarInfo3()
 	}
 }
 
+void GSM_Phone_N6510::FindCalendarDateDifference(GSM_DateTime *DT,long diff)
+{
+	time_t		timet;
+	struct tm	tmstruct;
+
+	tmstruct.tm_year	= DT->Year - 1900;
+	tmstruct.tm_mon	 	= DT->Month - 1;
+	tmstruct.tm_mday	= DT->Day;
+	tmstruct.tm_hour	= DT->Hour;
+	tmstruct.tm_min	 	= DT->Minute;
+	tmstruct.tm_sec	 	= DT->Second;
+	tmstruct.tm_isdst       = -1;
+
+	timet = mktime(&tmstruct);
+	timet -= diff;
+
+	memcpy(&tmstruct,localtime(&timet),sizeof(struct tm));
+	DT->Year	 = tmstruct.tm_year + 1900;
+	DT->Month	= tmstruct.tm_mon+1;
+	DT->Day	  	= tmstruct.tm_mday;
+	DT->Hour	 	= tmstruct.tm_hour;
+	DT->Minute       = tmstruct.tm_min;
+	DT->Second       = tmstruct.tm_sec;
+}
+
+GSM_Error GSM_Phone_N6510::ReplyGetNextToDo2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	int			     	Alarm;
+	GSM_ToDoEntry 		*ToDo = (GSM_ToDoEntry *)S;
+	GSM_ToDoSubEntry 	*Sub;
+	//GSM_DateTime		    	DT;
+
+	(*Debug)->Deb("RECEIVED: todo method 2\n");
+
+	ToDo->ClearAll();
+
+	Alarm = msg->Buffer.data()[14]*256*256*256+msg->Buffer.data()[15]*256*256;
+	Alarm +=msg->Buffer.data()[16]*256+msg->Buffer.data()[17];
+	if (Alarm != 0xffffffff) {
+		Sub = new GSM_ToDoSubEntry;
+		memcpy(&Sub->DT,NokiaGetDT(msg->Buffer.data()+28),sizeof(GSM_DateTime));
+		Sub->DT.Second = 0;
+		(*Debug)->Deb("   Start date time: %02i-%02i-%04i %02i:%02i:%02i\n",
+				Sub->DT.Day,Sub->DT.Month,Sub->DT.Year,Sub->DT.Hour,Sub->DT.Minute,Sub->DT.Second);
+
+		(*Debug)->Deb("   Alarm difference : %i\n",Alarm);
+
+		FindCalendarDateDifference(&Sub->DT,60*Alarm);
+
+		Sub->Type = ToDo_DateTime_ToneAlarm;
+		if (msg->Buffer.data()[22]==0x00 && msg->Buffer.data()[23]==0x00 &&
+		    msg->Buffer.data()[24]==0x00 && msg->Buffer.data()[25]==0x00) {
+			Sub->Type = ToDo_DateTime_SilentAlarm;
+		}
+
+		(*Debug)->Deb("   Alarm : %02i-%02i-%04i %02i:%02i:%02i\n",
+				Sub->DT.Day,Sub->DT.Month,Sub->DT.Year,Sub->DT.Hour,Sub->DT.Minute,Sub->DT.Second);
+		
+		ToDo->AddSubEntry(Sub);
+	}
+
+	Sub = new GSM_ToDoSubEntry;
+	memcpy(&Sub->DT,NokiaGetDT(msg->Buffer.data()+34),sizeof(GSM_DateTime));
+	Sub->DT.Second = 0;
+	Sub->Type = ToDo_DateTime_End;
+	(*Debug)->Deb("   End time : %02i-%02i-%04i %02i:%02i:%02i\n",
+			Sub->DT.Day,Sub->DT.Month,Sub->DT.Year,Sub->DT.Hour,Sub->DT.Minute,Sub->DT.Second);
+	ToDo->AddSubEntry(Sub);
+
+	Sub = new GSM_ToDoSubEntry;
+	Sub->Type = ToDo_Priority;
+	switch (msg->Buffer.data()[44]) {
+		case 0x10: Sub->Priority = GSM_Priority_Low; 		break;
+		case 0x20: Sub->Priority = GSM_Priority_Medium; 	break;
+		case 0x30: Sub->Priority = GSM_Priority_High; 		break;
+		default	 : delete (Sub); return GSM_Return_Error(GSM_ERR_UNKNOWN);
+	}
+	ToDo->AddSubEntry(Sub);
+
+	if (msg->Buffer.data()[45]==0x01) {
+		Sub = new GSM_ToDoSubEntry;
+		Sub->Type = ToDo_Bool_Completed;
+		Sub->BoolValue = TRUE;
+		ToDo->AddSubEntry(Sub);
+	}
+
+	Sub = new GSM_ToDoSubEntry;
+	Sub->Type = ToDo_Text_Text;
+	Sub->Text.append(NokiaGetUnicodeSimple(msg->Buffer.data()+54,msg->Buffer.data()[50]*256+msg->Buffer.data()[51]),msg->Buffer.data()[50]*256+msg->Buffer.data()[51]);
+	ToDo->AddSubEntry(Sub);
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_Phone_N6510::ReplyGetNextNote(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_NoteEntry *Note = (GSM_NoteEntry *)S;
+
+	(*Debug)->Deb("RECEIVED: note method 3\n");
+
+	Note->Text.clear();
+	Note->Text.append(NokiaGetUnicodeSimple(msg->Buffer.data()+54,msg->Buffer.data()[50]*256+msg->Buffer.data()[51]),msg->Buffer.data()[50]*256+msg->Buffer.data()[51]);
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 GSM_Error GSM_Phone_N6510::ReplyGetNextCalendar3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	time_t			  timet;
-	struct tm		       tmstruct;
-	GSM_DateTime		    DT,DT2;
-	GSM_CalendarEntry	       *Calendar = (GSM_CalendarEntry *)S;
-	int			     Alarm,j;
-	BOOLEAN			 found = FALSE;
+	time_t			  	timet;
+	struct tm		       	tmstruct;
+	GSM_DateTime		    	DT,DT2;
+	GSM_CalendarEntry	       	*Calendar = (GSM_CalendarEntry *)S;
+	int			     	Alarm,j;
+	BOOLEAN			 	found = FALSE;
 	GSM_Calendar_SubEntryType       AlarmType = Calendar_DateTime_ToneAlarm;
 
 	(*Debug)->Deb("RECEIVED: calendar entry method 3\n");
 
+	Calendar->ClearAll();
+
 	switch(msg->Buffer.data()[27]) {
 	case 0x00:
 		(*Debug)->Deb("   reminder\n");
@@ -172,21 +337,21 @@ GSM_Error GSM_Phone_N6510::ReplyGetNextCalendar3(GSM_Protocol_Message *msg, Debu
 
 	if (Calendar->Type == Calendar_Type_Birthday) DT.Year = 2000;
 	tmstruct.tm_year	= DT.Year - 1900;
-	tmstruct.tm_mon	 = DT.Month - 1;
+	tmstruct.tm_mon	 	= DT.Month - 1;
 	tmstruct.tm_mday	= DT.Day;
 	tmstruct.tm_hour	= DT.Hour;
-	tmstruct.tm_min	 = DT.Minute;
-	tmstruct.tm_sec	 = DT.Second;
+	tmstruct.tm_min	 	= DT.Minute;
+	tmstruct.tm_sec	 	= DT.Second;
 	tmstruct.tm_isdst       = -1;
 
 	timet = mktime(&tmstruct);
 	timet -= 60 * Alarm;
 
 	memcpy(&tmstruct,localtime(&timet),sizeof(struct tm));
-	DT.Year	 = tmstruct.tm_year + 1900;
+	DT.Year	 	= tmstruct.tm_year + 1900;
 	DT.Month	= tmstruct.tm_mon+1;
-	DT.Day	  = tmstruct.tm_mday;
-	DT.Hour	 = tmstruct.tm_hour;
+	DT.Day	  	= tmstruct.tm_mday;
+	DT.Hour	 	= tmstruct.tm_hour;
 	DT.Minute       = tmstruct.tm_min;
 	DT.Second       = tmstruct.tm_sec;
 
@@ -202,45 +367,46 @@ GSM_Error GSM_Phone_N6510::ReplyGetNextCalendar3(GSM_Protocol_Message *msg, Debu
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::PrivGetCalendar3(GSM_CalendarEntry *Entry)
+GSM_Error GSM_Phone_N6510::PrivGetCalendar3NoteToDo2(void *Entry, int Location, int request)
 {
 	unsigned char	   Buff[] = {
 		NOKIA_FRAME1,0x7D,0x00,0x00,0x00,0x00,
 		0x00,0x99,	      // Location
 		0xff,0xff,0xff,0xff};
 
-	Buff[8] = Entry->Location / 256;
-	Buff[9] = Entry->Location % 256;
+	Buff[8] = Location / 256;
+	Buff[9] = Location % 256;
 
 	(*Debug)->Deb("SENT: getting calendar note method 3\n");
-	return Write(Buff, sizeof(Buff), 0x13, 4, ID_GetCalendar+ID,Entry);
+//return PrivGetCalendarNoteToDo3(Entry,(*Location),request);
+
+	//ID_GetCalendar
+	return Write(Buff, sizeof(Buff), 0x13, 4, request+ID,Entry);
 }
 
-GSM_Error GSM_Phone_N6510::GetNextCalendar3(GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max)
+GSM_Error GSM_Phone_N6510::GetNextCalendar3NoteToDo2(void *Entry, BOOLEAN start, int *Current, int *Max, int *Location, unsigned char Type, int request)
 {
 	GSM_Error error;
 
 	if (start == TRUE) {
-		error = GetCalendarInfo3();
+		error = GetCalendar3NoteToDo2Info(Type);
 		if (error.Code != GSM_ERR_NONE) return error;
 		CurrentCalendarNumber = 0;
 	}
 
-	Entry->ClearAll();
-
 	if (CurrentCalendarNumber >= CalendarLocations.Length) {
 		CalendarLocations.Locations.clear();
 		return GSM_Return_Error(GSM_ERR_EMPTY);
 	}
 
-	Entry->Location = CalendarLocations.Locations.data()[CurrentCalendarNumber];
+	(*Location) = CalendarLocations.Locations.data()[CurrentCalendarNumber];
 
 	CurrentCalendarNumber++;
 
 	*Current = CurrentCalendarNumber;
 	*Max = CalendarLocations.Length;
 
-	return PrivGetCalendar3(Entry);
+	return PrivGetCalendar3NoteToDo2(Entry,(*Location),request);
 }
 
 GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *NoteID)
@@ -260,7 +426,7 @@ GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *
 		}
 	}
 
-	error = GetCalendarInfo3();
+	error = GetCalendar3NoteToDo2Info(0x00);
 	if (error.Code != GSM_ERR_NONE) return error;
 
 	for (i=0;i<CalendarLocations.Locations.length();i++) {
@@ -288,7 +454,7 @@ GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *
 	}
 	if (error.Code != GSM_ERR_NONE) return error;
 
-	error = GetCalendarInfo3();
+	error = GetCalendar3NoteToDo2Info(0x00);
 	if (error.Code != GSM_ERR_NONE) return error;
 
 	for(i=0;i<CalendarLocations.Locations.length();i++) {
@@ -301,7 +467,8 @@ GSM_Error GSM_Phone_N6510::FindCalendarNoteType3(GSM_CalendarEntry *Entry, int *
 		}
 		if (found == TRUE) {
 			Calendar.Location = CalendarLocations.Locations.data()[i];
-			error = PrivGetCalendar3(&Calendar);
+			error = PrivGetCalendar3NoteToDo2(&Calendar,Calendar.Location,ID_GetCalendar);
+
 			if (error.Code != GSM_ERR_NONE) return error;
 
 			error = DeleteCalendar(&Calendar);
@@ -344,37 +511,37 @@ GSM_Error GSM_Phone_N6510::ReplyAddCalendar3(GSM_Protocol_Message *msg, DebugInf
 
 GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 {
-	int		     Loc;
-	GSM_DateTime	    Date,Date2;
-	time_t		  timet1, timet2;
-	unsignedstring	  Buffer,Buffer2;
+	int		     	Loc;
+	GSM_DateTime	    	Date,Date2;
+	time_t		  	timet1, timet2;
+	unsignedstring	  	Buffer,Buffer2;
 	GSM_CalendarSubEntry    *SubEntry, *Text = NULL, *Location = NULL;
 	GSM_CalendarSubEntry    *Phone = NULL, *DateStart = NULL, *Alarm = NULL, *DateEnd = NULL;
-	int		     RepeatEach = -1, RepeatDOW = -1, RepeatDay = -1, RepeatMonth = -1;
-	unsigned int	    diff;
-	GSM_Error	       error;
-	unsigned char	   req[54] = {
+	int		    	RepeatEach = -1, RepeatDOW = -1, RepeatDay = -1, RepeatMonth = -1;
+	unsigned int	    	diff;
+	GSM_Error	       	error;
+	unsigned char	   	req[54] = {
 		NOKIA_FRAME1, 0x65,
-		0x00,				   /* 0 = calendar, 1 = todo	       */
+		0x00,				   	/* 0 = calendar, 1 = todo	       */
 		0x00, 0x00, 0x00,
-		0x00, 0x00,			     /* location			     */
+		0x00, 0x00,			     	/* location			     */
 		0x00, 0x00, 0x00, 0x00,
-		0xFF, 0xFF, 0xFF, 0xFF,		 /* alarm				*/
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm				*/
 		0x80, 0x00, 0x00,
-		0x01,				   /* note icon			    */
-		0xFF, 0xFF, 0xFF, 0xFF,		 /* alarm type			   */
-		0x00,				   /* 0x02 or 0x00			 */
-		0x01,				   /* note type			    */
+		0x01,				   	/* note icon			    */
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm type			   */
+		0x00,				   	/* 0x02 or 0x00			 */
+		0x01,				   	/* note type			    */
 		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* start date/time		      */
 		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* end date/time			*/
-		0x00, 0x00,			     /* recurrance			   */
-		0x00, 0x00,			     /* birth year			   */
-		0x20,				   /* ToDo priority			*/
-		0x00,				   /* ToDo completed ?		     */
-		0x00, 0x00,			     /* How many times repeat cal note or 0  */
+		0x00, 0x00,			     	/* recurrance			   */
+		0x00, 0x00,			     	/* birth year			   */
+		0x20,				   	/* ToDo priority			*/
+		0x00,				   	/* ToDo completed ?		     */
+		0x00, 0x00,			     	/* How many times repeat cal note or 0  */
 		0x00,
-		0x00,				   /* note text length		     */
-		0x00,				   /* phone length/meeting place	   */
+		0x00,				   	/* note text length		     */
+		0x00,				   	/* phone length/meeting place	   */
 		0x00, 0x00, 0x00};
 	int NoteID;
 
@@ -527,21 +694,3 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	(*Debug)->Deb("SENT: Adding calendar note (method 3)\n");
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddCalendar+ID,Entry);
 }
-
-GSM_Error GSM_Phone_N6510::AddCalendar(GSM_CalendarEntry *Entry)
-{
-	if ((*Phones)->Feature("cal62")==TRUE) {
-		return DCT34->AddCalendar1(Entry);
-	} else {
-		return AddCalendar3(Entry);
-	}
-
-//      return AddCalendar3(Entry);
-//      return DCT34->AddCalendar2(Entry);
-//      return DCT34->AddCalendar1(Entry);
-}
-
-GSM_Error GSM_Phone_N6510::DeleteCalendar(GSM_CalendarEntry *Entry)
-{
-	return DCT34->DeleteCalendar(Entry);
-}
