@@ -3,6 +3,7 @@
 #include "../../../../cfg/config.h" //msvc2005
 #include "../../../protocol/gsmprot.h"
 #include "../../../misc/coding/coding.h"
+#include "../../../misc/files.h"
 
 //---------------- filesystem 1 (obsolete, entries identified by numbers) ---------------------------------------
 
@@ -47,7 +48,8 @@ GSM_Error GSM_Phone_N6510::DeleteFolder1(wchar_t *FolderID)
 	GSM_Error			error;
 
 	//phone allow for deleting non empty folders, we not
-	FInfo.Info.SetID(FolderID);
+	FInfo.Info.ID.clear();
+	FInfo.Info.ID.append(FolderID,UnicodeLength(FolderID));
 	error = GetFileFolderInfo1(&FInfo.Info);
 	if (error.Code !=GSM_ERR_NONE) return error;
 	if (FInfo.Info.Folder==TRUE) {
@@ -69,19 +71,20 @@ GSM_Error GSM_Phone_N6510::DeleteFolder1(wchar_t *FolderID)
 
 GSM_Error GSM_Phone_N6510::ReplyAddFolder1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_FileFolderInfo 	*FInfo = (GSM_FileFolderInfo *)S;
+	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
 	GSM_Error 		error;
 	unsigned char		buffer[10];
 	
 	(*Debug)->Deb("RECEIVED: filesystem 1, adding folder\n");
 
 	sprintf((char *)buffer,"c:\\%i",msg->Buffer.data()[8]*256+msg->Buffer.data()[9]);
-	FInfo->SetID(StringToUnicodeReturn((char *)buffer));
+	FInfo->ID.clear();
+	FInfo->ID.append(StringToUnicodeReturn((char *)buffer),UnicodeLength(StringToUnicodeReturn((char *)buffer)));
 
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::AddFolder1(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::AddFolder1(FileFolderInfo *FInfo)
 {
 	GSM_Error		error;
 	unsignedstring 		bufferstring;
@@ -90,27 +93,27 @@ GSM_Error GSM_Phone_N6510::AddFolder1(GSM_FileFolderInfo *FInfo)
 		0x00, 0x00,	     // parent folder ID
 		0x00, 0x00, 0x00, 0xE8};
 
-	Add[8] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) / 256;
-	Add[9] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) % 256;
+	Add[8] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) / 256;
+	Add[9] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) % 256;
 	memset(Add+14, 0x00, 300);
-	NokiaSetUnicodeString(FInfo->GetName(),&bufferstring);
+	NokiaSetUnicodeString(FInfo->Name.data(),&bufferstring);
 	memcpy(Add+14,bufferstring.data(),bufferstring.size());
 	Add[233] = 0x02;
 	Add[235] = 0x01;
-	Add[236] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) / 256;
-	Add[237] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) % 256;
+	Add[236] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) / 256;
+	Add[237] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) % 256;
 
 	(*Debug)->Deb("SENT: filesystem 1, adding folder\n");
 	error = Write(Add, 246, 0x6D, 4, ID_AddFolder+ID,FInfo);
 
-	if (!strcmp(UnicodeToStringReturn(FInfo->GetID()),"0")) return GSM_Return_Error(GSM_ERR_FILE_EXIST);
+	if (!strcmp(UnicodeToStringReturn(FInfo->ID.data()),"0")) return GSM_Return_Error(GSM_ERR_FILE_EXIST);
 
 	return error;
 }
 
 GSM_Error GSM_Phone_N6510::ReplyAddFilePart1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_FileFolderInfo 	*FInfo = (GSM_FileFolderInfo *)S;
+	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
 	char			buffer[10];
 	wchar_t			name[10];
 
@@ -146,16 +149,16 @@ GSM_Error GSM_Phone_N6510::AddFilePart1(GSM_File *File, int *Pos)
 		0x01, 0x28};	     // buffer len
 
 	if (*Pos == 0) {
-		AddHeader[8] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) / 256;
-		AddHeader[9] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) % 256;
+		AddHeader[8] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) / 256;
+		AddHeader[9] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) % 256;
 		memset(AddHeader+14, 0x00, 300);
-		NokiaSetUnicodeString(File->Info.GetName(),&bufferstring);
+		NokiaSetUnicodeString(File->Info.Name.data(),&bufferstring);
 		memcpy(AddHeader+14,bufferstring.data(),bufferstring.size());
 		AddHeader[222] = File->Buffer.size() / (256*256*256);
 		AddHeader[223] = File->Buffer.size() / (256*256);
 		AddHeader[224] = File->Buffer.size() / 256;
 		AddHeader[225] = File->Buffer.size() % 256;
-		sprintf(buffer,"%s",UnicodeToStringReturn(File->Info.GetName()));
+		sprintf(buffer,"%s",UnicodeToStringReturn(File->Info.Name.data()));
 		       if (StringCaseStr(buffer,".jpg")!=NULL)  { AddHeader[231]=0x02; AddHeader[233]=0x01;
 		} else if (StringCaseStr(buffer,".jpeg")!=NULL) { AddHeader[231]=0x02; AddHeader[233]=0x01;
 		} else if (StringCaseStr(buffer,".bmp") !=NULL) { AddHeader[231]=0x02; AddHeader[233]=0x02;
@@ -170,8 +173,8 @@ GSM_Error GSM_Phone_N6510::AddFilePart1(GSM_File *File, int *Pos)
 		} else if (StringCaseStr(buffer,".jar") !=NULL) { AddHeader[231]=0x10; AddHeader[233]=0x01;
 		} else {					  AddHeader[231]=0x01; AddHeader[233]=0x05;}
 		AddHeader[235] = 0x01;
-		AddHeader[236] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) / 256;
-		AddHeader[237] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) % 256;
+		AddHeader[236] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) / 256;
+		AddHeader[237] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) % 256;
 		if (File->Info.DRMForwardLock) 	AddHeader[238] = 0x01; //Nokia forward lock
 		if (File->Info.Hidden)    	AddHeader[241] = 0x01;
 		if (File->Info.System)    	AddHeader[242] = 0x01; //fixme
@@ -184,8 +187,8 @@ GSM_Error GSM_Phone_N6510::AddFilePart1(GSM_File *File, int *Pos)
 	j = 2000;
 	if (File->Info.Size - *Pos < 2000) j = File->Info.Size - *Pos;
 
-	AddPart[8]  = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) / 256;
-	AddPart[9]  = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) % 256;
+	AddPart[8]  = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) / 256;
+	AddPart[9]  = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) % 256;
 	AddPart[12] = j / 256;
 	AddPart[13] = j % 256;
 
@@ -223,8 +226,8 @@ GSM_Error GSM_Phone_N6510::GetFileCheckSum1(GSM_File *File,unsigned int *CheckSu
 	unsigned char req[] = {NOKIA_FRAME1, 0x42, 0x00, 0x00, 0x00, 0x01,
 			       0x00, 0x1E};    // file ID
 
-	req[8] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) / 256;
-	req[9] = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) % 256;
+	req[8] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) / 256;
+	req[9] = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) % 256;
 
 	(*Debug)->Deb("SENT: filesystem 1, getting file checksum\n");
 	return Write(req, sizeof(req), 0x6D, 4, ID_GetFileCheckSum+ID,CheckSum);
@@ -242,8 +245,8 @@ GSM_Error GSM_Phone_N6510::GetFilePart1(GSM_File *File)
 		0x03, 0xE8}; 			//length
 
 	old     = File->Buffer.size();
-	req[8]  = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) / 256;
-	req[9]  = atoi(UnicodeToStringReturn(File->Info.GetID()+3)) % 256;
+	req[8]  = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) / 256;
+	req[9]  = atoi(UnicodeToStringReturn(File->Info.ID.data()+3)) % 256;
 	req[10] = old / (256*256*256);
 	req[11] = old / (256*256);
 	req[12] = old / 256;
@@ -267,7 +270,7 @@ GSM_Error GSM_Phone_N6510::GetFilePart1(GSM_File *File)
 
 GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_FileFolderInfo 	*FInfo = (GSM_FileFolderInfo *)S;
+	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
 	int 			i;
 	GSM_Error		error;
 
@@ -278,13 +281,13 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo1(GSM_Protocol_Message *msg, Debug
 		if (msg->Buffer.size() == 14) {
 			(*Debug)->Deb("  file or folder not available ?\n");
 			error.Code=GSM_ERR_FILE_FOLDER_NOT_EXIST;
-			error.Parameter.append((const wchar_t *)FInfo->GetID(),UnicodeLength(FInfo->GetID()));
+			error.Parameter.append((const wchar_t *)FInfo->ID.data(),UnicodeLength(FInfo->ID.data()));
 			return error;
 		}
 
 		FInfo->SetName(NokiaGetUnicodeString(msg->Buffer.data()+10));
-		if (!strncmp(UnicodeToStringReturn(FInfo->GetName()),"GMSTemp",7)) return GSM_Return_Error(GSM_ERR_EMPTY);
-		if (UnicodeLength(FInfo->GetName()) == 0) return GSM_Return_Error(GSM_ERR_UNKNOWN);
+		if (!strncmp(UnicodeToStringReturn(FInfo->Name.data()),"GMSTemp",7)) return GSM_Return_Error(GSM_ERR_EMPTY);
+		if (UnicodeLength(FInfo->Name.data()) == 0) return GSM_Return_Error(GSM_ERR_UNKNOWN);
 
 		i = msg->Buffer.data()[8]*256+msg->Buffer.data()[9];
 
@@ -319,7 +322,7 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo1(GSM_Protocol_Message *msg, Debug
 	}
 }
 
-GSM_Error GSM_Phone_N6510::GetFileFolderInfo1(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::GetFileFolderInfo1(FileFolderInfo *FInfo)
 {
 	GSM_Error		error;
 	unsigned char 		Buffer[] = {
@@ -329,8 +332,8 @@ GSM_Error GSM_Phone_N6510::GetFileFolderInfo1(GSM_FileFolderInfo *FInfo)
 		0x00, 0x00, 0x01,
 		0x00, 0x01};    /* Folder or file ID */
 
-	Buffer[8] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) / 256;
-	Buffer[9] = atoi(UnicodeToStringReturn(FInfo->GetID()+3)) % 256;
+	Buffer[8] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) / 256;
+	Buffer[9] = atoi(UnicodeToStringReturn(FInfo->ID.data()+3)) % 256;
 
 	Buffer[3] = 0x14; Buffer[4] = 0x01;
 	(*Debug)->Deb("SENT: filesystem 1, getting file/folder info\n");
@@ -348,7 +351,7 @@ GSM_Error GSM_Phone_N6510::GetFileFolderInfo1(GSM_FileFolderInfo *FInfo)
 GSM_Error GSM_Phone_N6510::ReplyGetFolderInfoList1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
 	GSM_FileFolderInfoList 	*FInfo = (GSM_FileFolderInfoList *)S;
-	GSM_FileFolderInfo 	*Info;
+	FileFolderInfo 	*Info;
 	wchar_t 		name[20];
 	char			buffer[20];
 	int 			i;
@@ -360,13 +363,13 @@ GSM_Error GSM_Phone_N6510::ReplyGetFolderInfoList1(GSM_Protocol_Message *msg, De
 
 	error.Code = GSM_ERR_EMPTY;
 	for (i=0;i<(msg->Buffer.data()[8]*256+msg->Buffer.data()[9]);i++) {
-		Info = new GSM_FileFolderInfo;
+		Info = new FileFolderInfo;
 
 		sprintf(buffer,"c:\\%i",msg->Buffer.data()[13+i*4-1]*256 + msg->Buffer.data()[13+i*4]);
 		StringToUnicode(buffer,name);
 
 		Info->SetID(name);
-		(*Debug)->Deb("  %s\n",UnicodeToStringReturn(Info->GetID()));
+		(*Debug)->Deb("  %s\n",UnicodeToStringReturn(Info->ID.data()));
 
 		FInfo->AddSubEntry(Info);
 
@@ -384,8 +387,8 @@ GSM_Error GSM_Phone_N6510::GetFolderInfoList1(GSM_FileFolderInfoList *FInfo, BOO
 		0x00, 0x00, 0x01,
 		0x00, 0x01};    /* Folder or file ID */
 
-	Buffer[8] = atoi(UnicodeToStringReturn(FInfo->Info.GetID()+3)) / 256;
-	Buffer[9] = atoi(UnicodeToStringReturn(FInfo->Info.GetID()+3)) % 256;
+	Buffer[8] = atoi(UnicodeToStringReturn(FInfo->Info.ID.data()+3)) / 256;
+	Buffer[9] = atoi(UnicodeToStringReturn(FInfo->Info.ID.data()+3)) % 256;
 
 	FInfo->SubEntryFullData = FALSE;
 
@@ -495,7 +498,7 @@ GSM_Error GSM_Phone_N6510::DeleteFolder2(wchar_t *FolderID)
 
 GSM_Error GSM_Phone_N6510::ReplyAddFolder2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_FileFolderInfo 	*FInfo = (GSM_FileFolderInfo *)S;
+	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
 	GSM_Error 		error;
 	int			Len;
 	wchar_t			*Buf;
@@ -508,19 +511,19 @@ GSM_Error GSM_Phone_N6510::ReplyAddFolder2(GSM_Protocol_Message *msg, DebugInfo
 	} else if (msg->Buffer.data()[4] == 0x04) {
 		(*Debug)->Deb("  folder already exist\n");
 
-		Len = UnicodeLength(FInfo->GetID());
-		if (UnicodeToStringReturn(FInfo->GetID())[Len-1] != '\\' &&
-	            UnicodeToStringReturn(FInfo->GetID())[Len-1] != '/') {
+		Len = UnicodeLength(FInfo->ID.data());
+		if (UnicodeToStringReturn(FInfo->ID.data())[Len-1] != '\\' &&
+	            UnicodeToStringReturn(FInfo->ID.data())[Len-1] != '/') {
 			Len ++;
 		}
-		Len+=UnicodeLength(FInfo->GetName());
+		Len+=UnicodeLength(FInfo->Name.data());
 		Buf=(wchar_t *)malloc((Len+1)*sizeof(wchar_t));
-		CopyUnicode(FInfo->GetID(),Buf);
+		CopyUnicode(FInfo->ID.data(),Buf);
 		if (Buf[UnicodeLength(Buf)-1] != '\\' &&
 		    Buf[UnicodeLength(Buf)-1] != '/') {
 			StringToUnicode("\\",Buf+UnicodeLength(Buf));
 		}
-		CopyUnicode(FInfo->GetName(),Buf+UnicodeLength(Buf));
+		CopyUnicode(FInfo->Name.data(),Buf+UnicodeLength(Buf));
 
 		error.Code=GSM_ERR_FOLDER_EXIST;
 		error.Parameter.append(Buf,UnicodeLength(Buf));
@@ -531,7 +534,7 @@ GSM_Error GSM_Phone_N6510::ReplyAddFolder2(GSM_Protocol_Message *msg, DebugInfo
 	} else if (msg->Buffer.data()[4] == 0x06) {
 		(*Debug)->Deb("  parent folder not available\n");
 		error.Code=GSM_ERR_FOLDER_NOT_EXIST;
-		error.Parameter.append((const wchar_t *)FInfo->GetID(),UnicodeLength(FInfo->GetID()));
+		error.Parameter.append((const wchar_t *)FInfo->ID.data(),UnicodeLength(FInfo->ID.data()));
 		return error;
 	} else if (msg->Buffer.data()[4] == 0x0C) {
 		(*Debug)->Deb("  probably no memory card\n");
@@ -540,25 +543,25 @@ GSM_Error GSM_Phone_N6510::ReplyAddFolder2(GSM_Protocol_Message *msg, DebugInfo
 	return GSM_Return_Error(GSM_ERR_FRAME_CONTENT_UNKNOWN);
 }
 
-GSM_Error GSM_Phone_N6510::AddFolder2(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::AddFolder2(FileFolderInfo *FInfo)
 {
 	unsignedstring 	Buffer;
 	int		Len;
 	wchar_t		*Buf;
 
-	Len = UnicodeLength(FInfo->GetID());
-	if (UnicodeToStringReturn(FInfo->GetID())[Len-1] != '\\' &&
-            UnicodeToStringReturn(FInfo->GetID())[Len-1] != '/') {
+	Len = UnicodeLength(FInfo->ID.data());
+	if (UnicodeToStringReturn(FInfo->ID.data())[Len-1] != '\\' &&
+            UnicodeToStringReturn(FInfo->ID.data())[Len-1] != '/') {
 		Len ++;
 	}
-	Len+=UnicodeLength(FInfo->GetName());
+	Len+=UnicodeLength(FInfo->Name.data());
 	Buf=(wchar_t *)malloc((Len+1)*sizeof(wchar_t));
-	CopyUnicode(FInfo->GetID(),Buf);
+	CopyUnicode(FInfo->ID.data(),Buf);
 	if (Buf[UnicodeLength(Buf)-1] != '\\' &&
 	    Buf[UnicodeLength(Buf)-1] != '/') {
 		StringToUnicode("\\",Buf+UnicodeLength(Buf));
 	}
-	CopyUnicode(FInfo->GetName(),Buf+UnicodeLength(Buf));
+	CopyUnicode(FInfo->Name.data(),Buf+UnicodeLength(Buf));
 
 	MakeFileSystemFrame2(&Buffer, Buf, 0x64);
 
@@ -568,7 +571,7 @@ GSM_Error GSM_Phone_N6510::AddFolder2(GSM_FileFolderInfo *FInfo)
 	return Write((unsigned char *)Buffer.data(), Buffer.size(), 0x6D, 4, ID_AddFolder+ID,FInfo);
 }
 
-GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, DebugInfo **Debug, GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, DebugInfo **Debug, FileFolderInfo *FInfo)
 {
 	GSM_Error error;
 
@@ -577,7 +580,7 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, D
 	if (msg->Buffer.data()[4] == 0x06) {
 		(*Debug)->Deb("  file or folder not available ?\n");
 		error.Code=GSM_ERR_FILE_FOLDER_NOT_EXIST;
-		error.Parameter.append((const wchar_t *)FInfo->GetID(),UnicodeLength(FInfo->GetID()));
+		error.Parameter.append((const wchar_t *)FInfo->ID.data(),UnicodeLength(FInfo->ID.data()));
 		return error;
 	}
 	if (msg->Buffer.data()[4] == 0x0C) {
@@ -592,7 +595,7 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, D
 			//no file
 			(*Debug)->Deb("  file not exist\n");
 			error.Code=GSM_ERR_FILE_FOLDER_NOT_EXIST;
-			error.Parameter.append((const wchar_t *)FInfo->GetID(),UnicodeLength(FInfo->GetID()));
+			error.Parameter.append((const wchar_t *)FInfo->ID.data(),UnicodeLength(FInfo->ID.data()));
 			return error;
 		case 0x0C:
 			(*Debug)->Deb("  probably no memory card\n");
@@ -638,7 +641,7 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, D
 
 GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	GSM_FileFolderInfo 	*FInfo = (GSM_FileFolderInfo *)S;
+	FileFolderInfo 	*FInfo = (FileFolderInfo *)S;
 	GSM_Error 		error;
 	wchar_t 		name[20];
 
@@ -651,15 +654,15 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2(GSM_Protocol_Message *msg, Debug
 	name[0] = 0;
 	FInfo->SetName(name);
 
-	if (UnicodeLength(FInfo->GetID())!=2 && UnicodeLength(FInfo->GetID())!=3) {
+	if (UnicodeLength(FInfo->ID.data())!=2 && UnicodeLength(FInfo->ID.data())!=3) {
 		return error;
 	}
 
-	if ((FInfo->GetID()[0] == 'a' || FInfo->GetID()[0] == 'A') ||
-	    (FInfo->GetID()[0] == 'd' || FInfo->GetID()[0] == 'D')) {
-		if (FInfo->GetID()[1] == ':' && FInfo->GetID()[2] == 0x00) FInfo->Folder=TRUE;
-		if ((FInfo->GetID()[2] == '\\' || FInfo->GetID()[2] == '/') &&
-		     FInfo->GetID()[3] == 0x00) {
+	if ((FInfo->ID.data()[0] == 'a' || FInfo->ID.data()[0] == 'A') ||
+	    (FInfo->ID.data()[0] == 'd' || FInfo->ID.data()[0] == 'D')) {
+		if (FInfo->ID.data()[1] == ':' && FInfo->ID.data()[2] == 0x00) FInfo->Folder=TRUE;
+		if ((FInfo->ID.data()[2] == '\\' || FInfo->ID.data()[2] == '/') &&
+		     FInfo->ID.data()[3] == 0x00) {
 			FInfo->Folder=TRUE;
 		}
 	}
@@ -667,11 +670,11 @@ GSM_Error GSM_Phone_N6510::ReplyGetFFolderInfo2(GSM_Protocol_Message *msg, Debug
 	return error;
 }
 
-GSM_Error GSM_Phone_N6510::GetFileFolderInfo2(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::GetFileFolderInfo2(FileFolderInfo *FInfo)
 {
 	unsignedstring Buffer;
 
-	MakeFileSystemFrame2(&Buffer, FInfo->GetID(), 0x6C);
+	MakeFileSystemFrame2(&Buffer, (wchar_t *)FInfo->ID.data(), 0x6C);
 
 	(*Debug)->Deb("SENT: filesystem 2, getting file/folder info\n");
 	return Write((unsigned char *)Buffer.data(), Buffer.size(), 0x6D, 4, ID_GetFileFolderInfo+ID,FInfo);
@@ -680,7 +683,7 @@ GSM_Error GSM_Phone_N6510::GetFileFolderInfo2(GSM_FileFolderInfo *FInfo)
 GSM_Error GSM_Phone_N6510::ReplyGetFolderInfoList2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
 	GSM_FileFolderInfoList 	*FInfo = (GSM_FileFolderInfoList *)S;
-	GSM_FileFolderInfo 	*Info;
+	FileFolderInfo 	*Info;
 	GSM_Error		error;
 	wchar_t 		*name;
 
@@ -693,15 +696,15 @@ GSM_Error GSM_Phone_N6510::ReplyGetFolderInfoList2(GSM_Protocol_Message *msg, De
 		return GSM_Return_Error(GSM_ERR_EMPTY);
 	}
 
-	Info = new GSM_FileFolderInfo;
+	Info = new FileFolderInfo;
 
 	Info->SetName(NokiaGetUnicodeString(msg->Buffer.data()+32));
-	(*Debug)->Deb("  %s\n",UnicodeToStringReturn(Info->GetName()));
+	(*Debug)->Deb("  %s\n",UnicodeToStringReturn(Info->Name.data()));
 
-	name = (wchar_t *)malloc((UnicodeLength(FInfo->Info.GetID())+1+UnicodeLength(Info->GetName())+1)*sizeof(wchar_t));
-	CopyUnicode(FInfo->Info.GetID(),name);
+	name = (wchar_t *)malloc((UnicodeLength(FInfo->Info.ID.data())+1+UnicodeLength(Info->Name.data())+1)*sizeof(wchar_t));
+	CopyUnicode(FInfo->Info.ID.data(),name);
 	StringToUnicode("\\",name+UnicodeLength(name));
-	CopyUnicode(Info->GetName(),name+UnicodeLength(name));
+	CopyUnicode(Info->Name.data(),name+UnicodeLength(name));
 
 	Info->SetID(name);
 
@@ -729,8 +732,8 @@ GSM_Error GSM_Phone_N6510::GetFolderInfoList2(GSM_FileFolderInfoList *FInfo, BOO
 	unsignedstring  Buffer;
 
 	if (Start) {
-		Buf=(wchar_t *)malloc((UnicodeLength(FInfo->Info.GetID())+3)*sizeof(wchar_t));
-		CopyUnicode(FInfo->Info.GetID(),Buf);
+		Buf=(wchar_t *)malloc((UnicodeLength(FInfo->Info.ID.data())+3)*sizeof(wchar_t));
+		CopyUnicode(FInfo->Info.ID.data(),Buf);
 		StringToUnicode("\\*",Buf+UnicodeLength(Buf));
 
 		MakeFileSystemFrame2(&Buffer, Buf, 0x68);
@@ -825,9 +828,9 @@ GSM_Error GSM_Phone_N6510::OpenFile2(GSM_File *File, BOOLEAN Create)
 		Buffer.push_back(0x00);//read only
 	}
 	Buffer.push_back(0x02);
-	Buffer.push_back((UnicodeLength(File->Info.GetID())*2+2)/256);
-	Buffer.push_back((UnicodeLength(File->Info.GetID())*2+2)%256);
-		FFolderPathGammu2Phone2(File->Info.GetID(),&Buffer);
+	Buffer.push_back((UnicodeLength(File->Info.ID.data())*2+2)/256);
+	Buffer.push_back((UnicodeLength(File->Info.ID.data())*2+2)%256);
+		FFolderPathGammu2Phone2((wchar_t *)File->Info.ID.data(),&Buffer);
 		Buffer.push_back(0x00); Buffer.push_back(0x00);
 	Buffer.push_back(0x00);
 	Buffer.push_back(0x00);
@@ -849,8 +852,8 @@ GSM_Error GSM_Phone_N6510::GetFilePart2(GSM_File *File)
 		0x00, 0x00, 0x03, 0xE8};	//buffer length
 
 	if (File->Buffer.size() == 0x00) {
-		Buf=(wchar_t *)malloc((UnicodeLength(File->Info.GetID())+1)*sizeof(wchar_t));
-		CopyUnicode(File->Info.GetID(),Buf);
+		Buf=(wchar_t *)malloc((UnicodeLength(File->Info.ID.data())+1)*sizeof(wchar_t));
+		CopyUnicode(File->Info.ID.data(),Buf);
 
 		for (old=UnicodeLength(Buf);old>=0;old--) {
 			if (Buf[old] == '\\' || Buf[old] == '/') break;
@@ -907,13 +910,13 @@ GSM_Error GSM_Phone_N6510::AddFilePart2(GSM_File *File, int *Pos)
 	//overwriting
 
 	if (*Pos == 0) {
-		name = (wchar_t *)malloc((UnicodeLength(File->Info.GetID())+1+UnicodeLength(File->Info.GetName())+1)*sizeof(wchar_t));
-		CopyUnicode(File->Info.GetID(),name);
+		name = (wchar_t *)malloc((UnicodeLength(File->Info.ID.data())+1+UnicodeLength(File->Info.Name.data())+1)*sizeof(wchar_t));
+		CopyUnicode(File->Info.ID.data(),name);
 		StringToUnicode("\\",name+UnicodeLength(name));
-		CopyUnicode(File->Info.GetName(),name+UnicodeLength(name));
+		CopyUnicode(File->Info.Name.data(),name+UnicodeLength(name));
 
 		File->Info.SetID(name);
-		(*Debug)->Deb("  %s\n",UnicodeToStringReturn(File->Info.GetID()));
+		(*Debug)->Deb("  %s\n",UnicodeToStringReturn(File->Info.ID.data()));
 
 		free(name);
 
@@ -952,8 +955,8 @@ GSM_Error GSM_Phone_N6510::AddFilePart2(GSM_File *File, int *Pos)
 	Buffer.push_back(0x01);
 	Buffer.push_back(0x00);
 	Buffer.push_back(0x86);
-	Buffer.push_back((UnicodeLength(File->Info.GetID())*2+2)/256);
-	Buffer.push_back((UnicodeLength(File->Info.GetID())*2+2)%256);
+	Buffer.push_back((UnicodeLength(File->Info.ID.data())*2+2)/256);
+	Buffer.push_back((UnicodeLength(File->Info.ID.data())*2+2)%256);
 	Buffer.push_back(File->Info.ModificationDateTime.Year / 256);
 	Buffer.push_back(File->Info.ModificationDateTime.Year % 256);
 	Buffer.push_back(File->Info.ModificationDateTime.Month);
@@ -962,7 +965,7 @@ GSM_Error GSM_Phone_N6510::AddFilePart2(GSM_File *File, int *Pos)
 	Buffer.push_back(File->Info.ModificationDateTime.Hour);
 	Buffer.push_back(File->Info.ModificationDateTime.Minute);
 	Buffer.push_back(File->Info.ModificationDateTime.Second);
-	FFolderPathGammu2Phone2(File->Info.GetID(),&Buffer);
+	FFolderPathGammu2Phone2((wchar_t *)File->Info.ID.data(),&Buffer);
 	Buffer.push_back(0x00); Buffer.push_back(0x00);
 	Buffer.push_back(0x00);
 	Buffer.push_back(0x00);
@@ -1021,7 +1024,7 @@ GSM_Error GSM_Phone_N6510::MakeFileSystemFrame2(unsignedstring *Buffer, wchar_t
 
 GSM_Error GSM_Phone_N6510::GetNextRootFolderID(wchar_t *ID, GSM_MemoryType *MemType)
 {
-	GSM_FileFolderInfo 	FInfo;
+	FileFolderInfo 	FInfo;
 	GSM_Error 		error;
 
 	//no filesystem
@@ -1100,12 +1103,12 @@ GSM_Error GSM_Phone_N6510::ReplyGetFilePart12(GSM_Protocol_Message *msg, DebugIn
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::GetFileFolderInfo(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::GetFileFolderInfo(FileFolderInfo *FInfo)
 {
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(FInfo->GetID(), &Num);
+	error = FileSystemFunc((wchar_t *)FInfo->ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (Num==1) return GetFileFolderInfo1(FInfo);
@@ -1117,7 +1120,7 @@ GSM_Error GSM_Phone_N6510::GetFolderInfoList(GSM_FileFolderInfoList *FInfo, BOOL
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(FInfo->Info.GetID(), &Num);
+	error = FileSystemFunc((wchar_t*)FInfo->Info.ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (Start) FInfo->ClearAll();
@@ -1131,7 +1134,7 @@ GSM_Error GSM_Phone_N6510::GetFilePart(GSM_File *File)
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(File->Info.GetID(), &Num);
+	error = FileSystemFunc((wchar_t *)File->Info.ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (File->Buffer.size() == 0x00) {
@@ -1140,7 +1143,7 @@ GSM_Error GSM_Phone_N6510::GetFilePart(GSM_File *File)
 
 		if (File->Info.Folder==TRUE) {
 			error.Code=GSM_ERR_MUST_BE_FILE;
-			error.Parameter.append((const wchar_t *)File->Info.GetID(),UnicodeLength(File->Info.GetID()));
+			error.Parameter.append((const wchar_t *)File->Info.ID.data(),UnicodeLength(File->Info.ID.data()));
 			return error;
 		}
 	}
@@ -1160,7 +1163,7 @@ GSM_Error GSM_Phone_N6510::GetMMSFilePart(GSM_File *File)
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(File->Info.GetID(), &Num);
+	error = FileSystemFunc((wchar_t *)File->Info.ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (File->Buffer.size() == 0x00) {
@@ -1169,10 +1172,10 @@ GSM_Error GSM_Phone_N6510::GetMMSFilePart(GSM_File *File)
 
 		if (File->Info.Folder==TRUE) {
 			error.Code=GSM_ERR_MUST_BE_FILE;
-			error.Parameter.append((const wchar_t *)File->Info.GetID(),UnicodeLength(File->Info.GetID()));
+			error.Parameter.append((const wchar_t *)File->Info.ID.data(),UnicodeLength(File->Info.ID.data()));
 			return error;
 		}
-		MMSFile.Info.SetID(File->Info.GetID());
+		MMSFile.Info.SetID((wchar_t *)File->Info.ID.data());
 		MMSFile.Buffer.clear();
 	}
 
@@ -1205,7 +1208,7 @@ GSM_Error GSM_Phone_N6510::AddFilePart(GSM_File *File, int *Pos)
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(File->Info.GetID(), &Num);
+	error = FileSystemFunc((wchar_t *)File->Info.ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (Num==1) return AddFilePart1(File,Pos);
@@ -1236,12 +1239,12 @@ GSM_Error GSM_Phone_N6510::DeleteFolder(wchar_t *FolderID)
 	return DeleteFolder2(FolderID);
 }
 
-GSM_Error GSM_Phone_N6510::AddFolder(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone_N6510::AddFolder(FileFolderInfo *FInfo)
 {
 	int 		Num;
 	GSM_Error 	error;
 
-	error = FileSystemFunc(FInfo->GetID(), &Num);
+	error = FileSystemFunc((wchar_t *)FInfo->ID.data(), &Num);
 	if (error.Code!=GSM_ERR_NONE) return error;
 
 	if (Num==1) return AddFolder1(FInfo);
@@ -1297,9 +1300,9 @@ GSM_Error GSM_Phone_N6510::GetJavaGamesFolderID(wchart *ID, BOOLEAN *NeedSubFold
 		if (JavaFInfo.GetNext(&JavaFInfoSubEntry) == FALSE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		error = GetFileFolderInfo(&JavaFInfoSubEntry->Info);
 		if (error.Code != GSM_ERR_NONE) return error;
-		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.GetName(),StringToUnicodeReturn("games"),-1)) {
+		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.Name.data(),StringToUnicodeReturn("games"),-1)) {
 			ID->clear();
-			ID->append(JavaFInfoSubEntry->Info.GetID(),UnicodeLength(JavaFInfoSubEntry->Info.GetID()));
+			ID->append(JavaFInfoSubEntry->Info.ID.data(),UnicodeLength(JavaFInfoSubEntry->Info.ID.data()));
 			*NeedSubFolder = TRUE;
 			return GSM_Return_Error(GSM_ERR_NONE);
 		}
@@ -1340,9 +1343,9 @@ GSM_Error GSM_Phone_N6510::GetJavaAppsFolderID(wchart *ID, BOOLEAN *NeedSubFolde
 		if (JavaFInfo.GetNext(&JavaFInfoSubEntry) == FALSE) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		error = GetFileFolderInfo(&JavaFInfoSubEntry->Info);
 		if (error.Code != GSM_ERR_NONE) return error;
-		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.GetName(),StringToUnicodeReturn("applications"),-1)) {
+		if (UnicodeCaseCmp(JavaFInfoSubEntry->Info.Name.data(),StringToUnicodeReturn("applications"),-1)) {
 			ID->clear();
-			ID->append(JavaFInfoSubEntry->Info.GetID(),UnicodeLength(JavaFInfoSubEntry->Info.GetID()));
+			ID->append(JavaFInfoSubEntry->Info.ID.data(),UnicodeLength(JavaFInfoSubEntry->Info.ID.data()));
 			*NeedSubFolder = TRUE;
 			return GSM_Return_Error(GSM_ERR_NONE);
 		}
