@@ -22,30 +22,30 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders2(GSM_SMSMMSFolders *Folders)
 
 	SubEntry = NULL;
 	while (List->GetNext(&SubEntry) == TRUE) {		
-		if (strstr(UnicodeToStringReturn(SubEntry->Info.GetName()),"predef")!=NULL) {
+		if (strstr(UnicodeToStringReturn(SubEntry->Info.Name.data()),"predef")!=NULL) {
 			continue;
-		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"exchange")) {
+		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"exchange")) {
 			continue;
 		}
 
 		ID.clear();
-		ID.append(SubEntry->Info.GetID());
+		ID.append(SubEntry->Info.ID.data());
 
-		if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"1")) {
+		if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"1")) {
 			Folders->Add(StringToUnicodeReturn("Inbox"),TRUE,TRUE,FALSE,MEM_PHONE,&ID,1,2);
 			Folders->Add(StringToUnicodeReturn("Inbox"),TRUE,TRUE,TRUE,MEM_PHONE,&ID,2,1);
 			continue;
 		}
 		buff[0] = 0;
-		if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"3")) {
+		if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"3")) {
 			sprintf(buff,"Sent items");
-		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"4")) {
+		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"4")) {
 			sprintf(buff,"Saved items");
-		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"5")) {
+		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"5")) {
 			sprintf(buff,"Drafts");
-		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"6")) {
+		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"6")) {
 			sprintf(buff,"Templates");
-		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"20")) {
+		} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"20")) {
 			sprintf(buff,"First user folder");
 		}
 		Num++;
@@ -54,9 +54,9 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders2(GSM_SMSMMSFolders *Folders)
 			Num++;
 			Folders->Add(StringToUnicodeReturn(buff),TRUE,FALSE,TRUE,MEM_PHONE,&ID,Num,Num-1);
 		} else {
-			Folders->Add(SubEntry->Info.GetName(),TRUE,FALSE,FALSE,MEM_PHONE,&ID,Num,Num+1);
+			Folders->Add((wchar_t *)SubEntry->Info.Name.data(),TRUE,FALSE,FALSE,MEM_PHONE,&ID,Num,Num+1);
 			Num++;
-			Folders->Add(SubEntry->Info.GetName(),TRUE,FALSE,TRUE,MEM_PHONE,&ID,Num,Num-1);
+			Folders->Add((wchar_t *)SubEntry->Info.Name.data(),TRUE,FALSE,TRUE,MEM_PHONE,&ID,Num,Num-1);
 		}
 	}
 
@@ -193,7 +193,7 @@ GSM_Error GSM_Phone_N6510::GetSMS2(GSM_SMSList *List, GSM_File *File)
 	SMS->SetDateTime(&File->Info.ModificationDateTime);
 
 	SMS->ID.clear();
-	SMS->ID.append((const wchar_t *)File->Info.GetID(),UnicodeLength(File->Info.GetID()));
+	SMS->ID.append((const wchar_t *)File->Info.ID.data(),UnicodeLength(File->Info.ID.data()));
 	SMS->Memory 	= MEM_PHONE;
 	SMS->Icon 	= SMS_Read;
 	List->Add(SMS);
@@ -214,7 +214,7 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSF
 		if (FoldersCacheSubEntry!=NULL) delete(FoldersCacheSubEntry);
 		FoldersCacheSubEntry = NULL;
 		while (FoldersCache.GetNext(&FoldersCacheSubEntry)) {
-			if (!wcscmp(FoldersCacheSubEntry->Info.Info.GetID(),(wchar_t *)SMSFolder->ID.data())) {
+			if (!wcscmp(FoldersCacheSubEntry->Info.Info.ID.data(),(wchar_t *)SMSFolder->ID.data())) {
 				Found = TRUE;
 				break;
 			}
@@ -262,7 +262,7 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSF
 		//getting next file from folder
 		SMSListPos++;
 		if (SMSCache2->Info.GetNext(&SMSSubEntry)) {
-			File.Info.SetID(SMSSubEntry->Info.GetID());
+			File.Info.SetID((wchar_t *)SMSSubEntry->Info.ID.data());
 			File.Buffer.clear();
 
 			while (true) {
@@ -285,7 +285,7 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSF
 					} else {
 						MMS->Folder = SMSFolder->Number+1;
 					}
-					MMS->File.Info.SetID(SMSSubEntry->Info.GetID());
+					MMS->File.Info.SetID((wchar_t *)SMSSubEntry->Info.ID.data());
 					*Current = SMSListPos;
 					return GSM_Return_Error(GSM_ERR_NONE);
 				}
@@ -406,11 +406,11 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders1(GSM_SMSMMSFolders *Folders)
 				error = GetFileFolderInfo(&SubEntry->Info);
 				if (error.Code != GSM_ERR_NONE) return error;
 			}
-			if (strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"Messages")) {
+			if (strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"Messages")) {
 				continue;
 			}
 	
-			error = ReadFolderToCache(SubEntry->Info.GetID(), &List);
+			error = ReadFolderToCache((wchar_t *)SubEntry->Info.ID.data(), &List);
 			if (error.Code != GSM_ERR_NONE) return error;
 	
 			SubEntry = NULL;
@@ -420,12 +420,12 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders1(GSM_SMSMMSFolders *Folders)
 					if (error.Code != GSM_ERR_NONE) return error;
 				}
 				ID2.clear();
-				ID2.append(SubEntry->Info.GetID());
+				ID2.append(SubEntry->Info.ID.data());
 				Inbox = FALSE;
-				if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"Inbox")) {
+				if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"Inbox")) {
 					Inbox = TRUE;
 				}
-				Folders->Add(SubEntry->Info.GetName(),TRUE,Inbox,TRUE,MEM_PHONE,&ID2,Num,-1);
+				Folders->Add((wchar_t *)SubEntry->Info.Name.data(),TRUE,Inbox,TRUE,MEM_PHONE,&ID2,Num,-1);
 				Num++;			
 			}
 			break;
@@ -443,20 +443,20 @@ GSM_Error GSM_Phone_N6510::GetSMSMMSFolders1(GSM_SMSMMSFolders *Folders)
 		while (List->GetNext(&SubEntry)) {
 			Inbox = FALSE;
 			buff[0] = 0;
-			if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"predefinbox")) {
+			if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"predefinbox")) {
 				sprintf(buff,"Inbox");
 				Inbox = TRUE;
-			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"predefoutbox")) {
+			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"predefoutbox")) {
 				sprintf(buff,"Outbox");
-			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"predefsent")) {
+			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"predefsent")) {
 				sprintf(buff,"Sent items");
-			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.GetName()),"predefdrafts")) {
+			} else if (!strcmp(UnicodeToStringReturn(SubEntry->Info.Name.data()),"predefdrafts")) {
 				sprintf(buff,"Drafts");
 			} else {
-				sprintf(buff,"%s",UnicodeToStringReturn(SubEntry->Info.GetName()));
+				sprintf(buff,"%s",UnicodeToStringReturn(SubEntry->Info.Name.data()));
 			}
 			ID2.clear();
-			ID2.append(SubEntry->Info.GetID());
+			ID2.append(SubEntry->Info.ID.data());
 			Folders->Add(StringToUnicodeReturn(buff),TRUE,Inbox,TRUE,MEM_PHONE,&ID2,Num,-1);
 			Num++;
 		}
@@ -707,7 +707,7 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSF
 			if (FoldersCacheSubEntry!=NULL) delete(FoldersCacheSubEntry);
 			FoldersCacheSubEntry = NULL;
 			while (FoldersCache.GetNext(&FoldersCacheSubEntry)) {
-				if (!wcscmp(FoldersCacheSubEntry->Info.Info.GetID(),(wchar_t *)SMSFolder->ID.data())) {
+				if (!wcscmp(FoldersCacheSubEntry->Info.Info.ID.data(),(wchar_t *)SMSFolder->ID.data())) {
 					Found = TRUE;
 					break;
 				}
@@ -756,7 +756,7 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSF
 		if (SMSCache2->Info.GetNext(&SMSSubEntry)) {
 			SMS->Folder = 0;
 			MMS->Folder = SMSFolder->Number;
-			MMS->File.Info.SetID(SMSSubEntry->Info.GetID());
+			MMS->File.Info.SetID((wchar_t *)SMSSubEntry->Info.ID.data());
 			*Current = SMSListPos;
 			return GSM_Return_Error(GSM_ERR_NONE);
 		}
