@@ -37,10 +37,11 @@ public:
         /*2*/   Info.push_back(GSM_Phone_Info("5140" , "NPL-5"  ,  "Nokia 5140"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("5140b", "NPL-4"  ,  "Nokia 5140"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("5140i", "RM-104" ,  "Nokia 5140i" ,"fbus|irdaphonet", ""));
+//5200 - RM-174
         /*2*/   Info.push_back(GSM_Phone_Info("6020" , "RM-30"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("6020b", "RM-31"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("6100" , "NPL-2"  ,  "Nokia 6100"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", ""));
-        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30--todo6610-"));
         /*1*/   Info.push_back(GSM_Phone_Info("6170" , "RM-47"  ,  "Nokia 6170"  ,"fbus|irdaphonet|dku2phonet|dku2", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("6220" , "RH-20"  ,  "Nokia 6220"  ,"fbus|irdaphonet|dku5fbus|dku5", "-file1only-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6230" , "RH-12"  ,  "Nokia 6230"  ,"fbus|irdaphonet|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1-"));
@@ -92,6 +93,7 @@ public:
         GSM_Error        GetCodeNameModel       (unsigned char *Model);
         GSM_Error        GetFirmwareVersion     (unsigned char *Firm);
         GSM_Error        GetFirmwareDate        (unsigned char *Dat);
+	GSM_Error 	 GetProductCode		(unsigned char *ProductCode);
         //date time
         GSM_Error        GetDateTime            (GSM_DateTime *DT);
         //phonebook memories
@@ -103,6 +105,14 @@ public:
         GSM_Error        GetNextCalendar        (GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max);
         GSM_Error        AddCalendar            (GSM_CalendarEntry *Entry);
         GSM_Error        DeleteCalendar         (GSM_CalendarEntry *Entry);
+        //notes
+        GSM_Error        GetNextNote		(GSM_NoteEntry *Entry, BOOLEAN start, int *Current, int *Max);
+        GSM_Error        AddNote		(GSM_NoteEntry *Entry);
+        GSM_Error        DeleteNote		(GSM_NoteEntry *Entry);
+        //todo
+        GSM_Error        GetNextToDo		(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max);
+        GSM_Error        AddToDo		(GSM_ToDoEntry *Entry);
+        GSM_Error        DeleteToDo		(GSM_ToDoEntry *Entry);
         //sms
         GSM_Error        GetSMSStatus           (GSM_SMSStatus *Status);
         GSM_Error        GetSMSC                (GSM_SMSC *SMSC);
@@ -113,9 +123,8 @@ public:
         //sms & mms
 	GSM_Error 	 GetSMSMMSFolders	(GSM_SMSMMSFolders *Folders);
 	GSM_Error      GetNextSMSMMSIDFromFolder(BOOLEAN start, GSM_SMSMMSFoldersSubEntry *SMSFolder, GSM_SMSList *SMS, GSM_MMSFile *MMS, int *Current, int *MaxInFolder);
-
         //filesystem
-        GSM_Error        GetFileFolderInfo      (GSM_FileFolderInfo *FInfo);
+        GSM_Error        GetFileFolderInfo      (FileFolderInfo *FInfo);
         GSM_Error        GetFolderInfoList      (GSM_FileFolderInfoList *FInfo, BOOLEAN Start);
         GSM_Error        GetNextRootFolderID    (wchar_t *ID, GSM_MemoryType *MemType);
         GSM_Error        GetFilePart            (GSM_File *File);
@@ -123,7 +132,7 @@ public:
         GSM_Error        AddFilePart            (GSM_File *File, int *Pos);
         GSM_Error        DeleteFile             (wchar_t *FileID);
         GSM_Error        DeleteFolder           (wchar_t *FolderID);
-        GSM_Error        AddFolder              (GSM_FileFolderInfo *FInfo);
+        GSM_Error        AddFolder              (FileFolderInfo *FInfo);
         GSM_Error        GetJavaGamesFolderID   (wchart *ID, BOOLEAN *NeedSubFolder, BOOLEAN Start);
         GSM_Error        GetJavaAppsFolderID    (wchart *ID, BOOLEAN *NeedSubFolder, BOOLEAN Start);
 private:
@@ -149,13 +158,15 @@ private:
         //Java folders
         GSM_FileFolderInfoList          JavaFInfo;
         GSM_FileFolderInfoListSubEntry  *JavaFInfoSubEntry;
-
-        GSM_Error        GetNextCalendar3       (GSM_CalendarEntry *Entry, BOOLEAN start, int *Current, int *Max);
-        GSM_Error        GetCalendarInfo3       ();
+	
+	//calendar,note,todo
+	void 		 FindCalendarDateDifference(GSM_DateTime *DT,long diff);
+	GSM_Error 	 GetNextCalendar3NoteToDo2(void *Entry, BOOLEAN start, int *Current, int *Max, int *Location, unsigned char Type, int request);
+	GSM_Error 	 PrivGetCalendar3NoteToDo2(void *Entry, int Location, int request);
+	GSM_Error 	 GetCalendar3NoteToDo2Info(unsigned char type);
         GSM_Error        AddCalendar3           (GSM_CalendarEntry *Entry);
         GSM_Error        GetFirstCalendarPos3   (int *Location);
 	GSM_Error 	 FindCalendarNoteType3	(GSM_CalendarEntry *Entry, int *NoteID);
-        GSM_Error        PrivGetCalendar3       (GSM_CalendarEntry *Entry);
         //sms
         GSM_Error        GetSMSFolderStatus1    (GSM_SMS_Loc *SMSLocations);
         GSM_Error        GetSMS1                (GSM_SMSList *List, wchart SMS_ID);
@@ -171,8 +182,8 @@ private:
         GSM_Error        DeleteSMS1             (GSM_SMSList *List);
         GSM_Error        DeleteSMS2             (GSM_SMSList *List);
         //filesystem
-        GSM_Error        GetFileFolderInfo1     (GSM_FileFolderInfo *FInfo);
-        GSM_Error        GetFileFolderInfo2     (GSM_FileFolderInfo *FInfo);
+        GSM_Error        GetFileFolderInfo1     (FileFolderInfo *FInfo);
+        GSM_Error        GetFileFolderInfo2     (FileFolderInfo *FInfo);
         GSM_Error        GetFolderInfoList1     (GSM_FileFolderInfoList *FInfo, BOOLEAN Start);
         GSM_Error        GetFolderInfoList2     (GSM_FileFolderInfoList *FInfo, BOOLEAN Start);
         GSM_Error        GetFilePart1           (GSM_File *File);
@@ -190,16 +201,20 @@ private:
         GSM_Error        DeleteFolder1          (wchar_t *FolderID);
         GSM_Error        DeleteFolder2          (wchar_t *FolderID);
         GSM_Error        DeleteFFolder1         (wchar_t *MyID);
-        GSM_Error        AddFolder1             (GSM_FileFolderInfo *FInfo);
-        GSM_Error        AddFolder2             (GSM_FileFolderInfo *FInfo);
+        GSM_Error        AddFolder1             (FileFolderInfo *FInfo);
+        GSM_Error        AddFolder2             (FileFolderInfo *FInfo);
         GSM_Error        MakeFileSystemFrame2   (unsignedstring *Buffer, wchar_t *Name, unsigned char ID);
         GSM_Error        FileSystemFunc         (wchar_t *ID, int *Num);
-
+	//pbk
         GSM_Error        ReplyGetPBKStatus      (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetIMEI           (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *IMEI);
         GSM_Error        ReplyGetPBK            (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
+	GSM_Error 	 ReplyGetProductCode	(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *ProductCode);
+	//calendar,todo,notes
+        GSM_Error        ReplyGetNextToDo2      (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
+        GSM_Error        ReplyGetNextNote       (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetNextCalendar3  (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
-        GSM_Error        ReplyGetCalendarInfo3  (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
+        GSM_Error        ReplyGetCalendarNoteToDoInfo3(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetDateTime       (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyAddCalendar3      (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetFirstCalPos3   (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
@@ -217,7 +232,7 @@ private:
         GSM_Error        ReplyGetFFolderInfo2   (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetFolderInfoList1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetFolderInfoList2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
-        GSM_Error        ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, DebugInfo **Debug, GSM_FileFolderInfo *FInfo);
+        GSM_Error        ReplyGetFFolderInfo2Part(GSM_Protocol_Message *msg, DebugInfo **Debug, FileFolderInfo *FInfo);
         GSM_Error        ReplyOpenFile2         (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyAddFilePart1      (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
         GSM_Error        ReplyGetFilePart12     (GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S);
