@@ -1,4 +1,4 @@
-/* (C) 2003 - 2005 by Marcin Wiacek www.mwiacek.com */
+/* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
 #include "backtext.cpp"
 #include "gsmback.h"
@@ -6,9 +6,11 @@
 void GSM_Backup::GetFileFunctions(GSM_Backup_FileFormatNum Num, GSM_Backup_FileFormatFunctions *Func)
 {
 	if (Num == Backup_Gammu) {
-		Func->PhonePBK = TRUE;
-		Func->SIMPBK = TRUE;
-		Func->Calendar = TRUE;
+		Func->PhonePBK 	= TRUE;
+		Func->SIMPBK 	= TRUE;
+		Func->Calendar 	= TRUE;
+		Func->ToDo 	= TRUE;
+		Func->Notes 	= TRUE;
 	}
 }
 
@@ -271,7 +273,7 @@ void GSM_Backup::LinkSMS()
 							NumberNum2++;
 							if (Number->PhoneNumber!=Number2->PhoneNumber) continue;
 							Found = TRUE;
-							for (z=0;z<NumberNum.length();z++) {
+							for (z=0;z<(int)NumberNum.length();z++) {
 								if (NumberNum.data()[z] == NumberNum2++) {
 									Found = FALSE;
 									break;
@@ -329,6 +331,8 @@ GSM_Backup::GSM_Backup()
 	Cal = NULL;
 	SMS = NULL;
 	MMS = NULL;
+	ToDo = NULL;
+	Notes = NULL;
 
         IMEI[0]=0;
 	Model[0]=0;
@@ -360,12 +364,26 @@ void GSM_Backup::Delete_Calendar()
 	Cal = NULL;
 }
 
+void GSM_Backup::Delete_ToDo()
+{
+	delete(ToDo);
+	ToDo = NULL;
+}
+
+void GSM_Backup::Delete_Notes()
+{
+	delete(Notes);
+	Notes = NULL;
+}
+
 GSM_Backup::~GSM_Backup()
 {
 	Delete_PBK();
 	Delete_Calendar();
 	Delete_SMS();
 	Delete_MMS();
+	Delete_Notes();
+	Delete_ToDo();
 }
 
 GSM_Error GSM_Backup::ReadFromFile(char *FileName)
@@ -422,6 +440,28 @@ BOOLEAN GSM_Backup::GetNext_PBK(GSM_Backup_PBKEntry **En)
 	return TRUE;
 }
 
+BOOLEAN GSM_Backup::GetNext_Note(GSM_Backup_NoteEntry **En)
+{
+	if ((*En) == NULL) {
+		(*En) = Notes;
+	} else {
+		(*En) = (*En)->GetNext();
+	}
+	if ((*En) == NULL) return FALSE;
+	return TRUE;
+}
+
+BOOLEAN GSM_Backup::GetNext_ToDo(GSM_Backup_ToDoEntry **En)
+{
+	if ((*En) == NULL) {
+		(*En) = ToDo;
+	} else {
+		(*En) = (*En)->GetNext();
+	}
+	if ((*En) == NULL) return FALSE;
+	return TRUE;
+}
+
 void GSM_Backup::Add_PBK(GSM_PBKEntry *En)
 {
 	GSM_Backup_PBKEntry *Entry,*Entry2;
@@ -454,6 +494,38 @@ void GSM_Backup::Add_Cal(GSM_CalendarEntry *En)
 	}
 }
 
+void GSM_Backup::Add_Note(GSM_NoteEntry *En)
+{
+	GSM_Backup_NoteEntry *Entry,*Entry2;
+
+	Entry = new GSM_Backup_NoteEntry;
+	Entry->SetEntry(En);
+
+	if (Notes == NULL) {
+		Notes = Entry;
+	} else {
+		Entry2 = Notes;
+		while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+		Entry2->SetNext(Entry);
+	}
+}
+
+void GSM_Backup::Add_ToDo(GSM_ToDoEntry *En)
+{
+	GSM_Backup_ToDoEntry *Entry,*Entry2;
+
+	Entry = new GSM_Backup_ToDoEntry;
+	Entry->SetEntry(En);
+
+	if (ToDo == NULL) {
+		ToDo = Entry;
+	} else {
+		Entry2 = ToDo;
+		while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+		Entry2->SetNext(Entry);
+	}
+}
+
 void GSM_Backup::Add_MMS(GSM_MMSFile *En)
 {
 	GSM_Backup_MMSEntry *Entry,*Entry2;
@@ -626,3 +698,71 @@ void GSM_Backup_MMSEntry::SetEntry(GSM_MMSFile *En)
 {
 	Entry = En;
 }
+
+/* ------------------------------------------------------------------------- */
+
+GSM_Backup_NoteEntry::GSM_Backup_NoteEntry()
+{
+	Next = NULL;
+	Entry = NULL;
+}
+
+GSM_Backup_NoteEntry::~GSM_Backup_NoteEntry()
+{
+	delete(Next);
+	delete(Entry);
+}
+
+void GSM_Backup_NoteEntry::SetNext(GSM_Backup_NoteEntry *Nxt)
+{
+	Next = Nxt;
+}
+
+GSM_Backup_NoteEntry *GSM_Backup_NoteEntry::GetNext()
+{
+	return Next;
+}
+
+GSM_NoteEntry *GSM_Backup_NoteEntry::GetEntry()
+{
+	return Entry;
+}
+
+void GSM_Backup_NoteEntry::SetEntry(GSM_NoteEntry *En)
+{
+	Entry = En;
+}
+
+/* ------------------------------------------------------------------------- */
+
+GSM_Backup_ToDoEntry::GSM_Backup_ToDoEntry()
+{
+	Next = NULL;
+	Entry = NULL;
+}
+
+GSM_Backup_ToDoEntry::~GSM_Backup_ToDoEntry()
+{
+	delete(Next);
+	delete(Entry);
+}
+
+void GSM_Backup_ToDoEntry::SetNext(GSM_Backup_ToDoEntry *Nxt)
+{
+	Next = Nxt;
+}
+
+GSM_Backup_ToDoEntry *GSM_Backup_ToDoEntry::GetNext()
+{
+	return Next;
+}
+
+GSM_ToDoEntry *GSM_Backup_ToDoEntry::GetEntry()
+{
+	return Entry;
+}
+
+void GSM_Backup_ToDoEntry::SetEntry(GSM_ToDoEntry *En)
+{
+	Entry = En;
+}
