@@ -582,7 +582,10 @@ GSM_Error GSM_MMSDecodedFile::Read(GSM_File *File)
 
 		//header
 		type = DecodeContentType(&File->Buffer, &pos, &buff3, &buff2, &name, version);
-		if (name.length()!=0) SubEntry->File.Info.SetName((wchar_t *)name.data());
+		if (name.length()!=0) {
+			SubEntry->File.Info.Name.clear();
+			SubEntry->File.Info.Name.append((wchar_t *)name.data(),UnicodeLength((wchar_t *)name.data()));
+		}
 		SubEntry->Text.append(StringToUnicodeReturn((char *)buff3.data()),UnicodeLength(StringToUnicodeReturn((char *)buff3.data())));
 		SubEntry->Text2.append(StringToUnicodeReturn((char *)buff2.data()),UnicodeLength(StringToUnicodeReturn((char *)buff2.data())));
 //		if (type == -1) return GSM_Return_Error(GSM_ERR_UNKNOWN);
