@@ -499,12 +499,11 @@ GSM_Error CheckRSS(unsignedstring *StableStr, unsignedstring *TestStr)
 	
 	X.push_back(0x00);
 
-	error = File.ReadFromWWW("www.mwiacek.com","gsm/soft/gplus.rss");
-	if (error.Code!=GSM_ERR_NONE) return error;
-
 	StableStr->clear();
 	TestStr->clear();
 
+	if (!File.ReadFromWWW("www.mwiacek.com","gsm/soft/gplus.rss")) return GSM_Return_Error(GSM_ERR_UNKNOWN);
+	
 	while (pos < File.Buffer.size()) {
 		if (File.Buffer.data()[pos] != 10) {
 			pos++;
