@@ -4,7 +4,7 @@
 #include <stdarg.h>
 
 #include "../cfg/config.h"
-#include "../common/misc/ini.h"
+#include "../common/misc/files.h"
 #include "../common/misc/misc.h"
 #include "../common/misc/coding/coding.h"
 #include "../common/gsmstate.h"
@@ -441,6 +441,27 @@ void GetAllCalendar(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *a
 	}
 }
 
+void GetAllNotes(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
+{
+        GSM_Error 		error;
+	GSM_NoteEntry	 	Entry;
+	BOOLEAN			start = TRUE;
+	int Current,Max;
+
+	error = s->Open(CFG);
+	PrintError(error);
+
+	while (1) {
+		error = s->Phones->Current->GetNextNote(&Entry,start,&Current,&Max);
+		if (error.Code == GSM_ERR_EMPTY) break;
+		PrintError(error);
+
+		printf("text %s\n",UnicodeToStringReturn(Entry.Text.data()));
+
+		start = FALSE;
+	}
+}
+
 void GetDateTime(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
 {
         GSM_Error 		error;
@@ -643,6 +664,7 @@ static CommandLineFunction CommandLineFunctions[] = {
 	"--getmemory",		2, 3, GetMemory,     "ME|SM location",
 	"--restore",		1, 1, Restore,       "",
 	"--getallcalendar",	0, 0, GetAllCalendar,"",
+	"--getallnotes",	0, 0, GetAllNotes,   "",
 	"--getdatetime",	0, 0, GetDateTime,   "",
 	"--clearall",		0, 0, ClearAll,	     "",
 	"--getmmsfolders",	0, 0, GetMMSFolders, "",
@@ -675,6 +697,22 @@ void Help(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[])
 		printf("%s %s\n",CommandLineFunctions[i].Parameter,CommandLineFunctions[i].Params);
 		i++;
 	}
+
+
+//	GSM_Error error;
+//	GSM_File 	File;
+
+//	error = File.ReadFromWWW("europe.nokia.com","/A4305060");
+//	PrintError(error);
+//	printf("%s",File.Buffer.data());
+
+//	error = File.ReadFromWWW("europe.nokia.com","/appmanager/UnitedStatesEnglishEUROPE_NOKIA_COM_3/Get_support;JSESSIONID_NCOM=RpcxFxpbBLZptp2jG51KZpQKysryZrMTsw6LtJLS75M1TvrWjZBK!-648759238?_nfpb=true&_windowLabel=T42560468101167294708450&_pageLabel=P324575&wsrp-urlType=blockingAction&wsrp-url=&wsrp-requiresRewrite=&wsrp-navigationalState=&wsrp-interactionState=_action%3D%2Fpageflows%2FSoftwareVersion%2FgetVersion&wsrp-mode=&wsrp-windowState=");
+//	PrintError(error);
+//	printf("%s",File.Buffer.data());
+
+//	error = File.ReadFromWWW("europe.nokia.com","/appmanager/UnitedStatesEnglishEUROPE_NOKIA_COM_3/Get_support;JSESSIONID_NCOM=d9VdFxxBy2Gy9QJhnqKhPqVV61Nrj23cwx1P98p4b1lyXVHrh88Y!-648759238?_nfpb=true&_windowLabel=T42560468101167294708450&_pageLabel=P324575&wsrp-urlType=blockingAction&wsrp-url=&wsrp-requiresRewrite=&wsrp-navigationalState=&wsrp-interactionState=_action%3D%2Fpageflows%2FSoftwareVersion%2FgetVersion&wsrp-mode=&wsrp-windowState=");
+//	PrintError(error);
+//	printf("%s",File.Buffer.data());
 }
 
 int main2(int argc, char *argv[])
