@@ -38,10 +38,10 @@
 #include <wx/calctrl.h>
 #include <wx/mediactrl.h>
 #include <wx/listbox.h>
-#include <wx/splitter.h>
 #include <wx/textctrl.h>
 #include <wx/combobox.h>
 #include <wx/listctrl.h>
+#include <wx/splitter.h>
 #include <wx/button.h>
 #include <wx/panel.h>
 #include <wx/notebook.h>
@@ -69,6 +69,42 @@ class PhoneFrm : public wxMDIChildFrame
 		////GUI Control Declaration Start
 		wxMenu *MMSSingleUpWxPopupMenu;
 		wxMenu *SMSSingleUpWxPopupMenu;
+		wxListCtrl *JavaDownWxListCtrl;
+		wxGridSizer *WxGridSizer16;
+		wxPanel *WxPanel27;
+		wxListCtrl *JavaUpWxListCtrl;
+		wxGridSizer *WxGridSizer15;
+		wxPanel *WxPanel26;
+		wxSplitterWindow *WxSplitterWindow8;
+		wxBoxSizer *WxBoxSizer19;
+		wxButton *JavaGetWxButton;
+		wxPanel *WxPanel25;
+		wxBoxSizer *WxBoxSizer18;
+		wxPanel *JavaWxNoteBookPage;
+		wxListCtrl *ToDoDownWxListCtrl;
+		wxGridSizer *WxGridSizer14;
+		wxPanel *WxPanel23;
+		wxListCtrl *ToDoUpWxListCtrl;
+		wxGridSizer *WxGridSizer13;
+		wxPanel *WxPanel21;
+		wxSplitterWindow *WxSplitterWindow6;
+		wxBoxSizer *WxBoxSizer16;
+		wxButton *ToDoGetWxButton;
+		wxPanel *WxPanel20;
+		wxBoxSizer *WxBoxSizer15;
+		wxPanel *ToDoWxNoteBookPage;
+		wxTextCtrl *NotesWxMemo;
+		wxGridSizer *WxGridSizer12;
+		wxPanel *WxPanel19;
+		wxListCtrl *NotesWxListCtrl;
+		wxGridSizer *WxGridSizer11;
+		wxPanel *WxPanel18;
+		wxSplitterWindow *WxSplitterWindow5;
+		wxBoxSizer *WxBoxSizer14;
+		wxButton *NotesGetWxButton;
+		wxPanel *WxPanel17;
+		wxBoxSizer *WxBoxSizer13;
+		wxPanel *NotesWxNoteBookPage;
 		wxListCtrl *CalendarDownWxListCtrl;
 		wxGridSizer *WxGridSizer10;
 		wxPanel *WxPanel15;
@@ -150,14 +186,19 @@ class PhoneFrm : public wxMDIChildFrame
 		wxBoxSizer *WxBoxSizer2;
 		wxPanel *PhoneBookWxNoteBookPage;
 		wxListCtrl *FilesWxListCtrl;
-		wxButton *JavaWxButton;
 		wxButton *AddFileWxButton;
 		wxButton *FilesGetWxButton;
 		wxPanel *WxPanel1;
 		wxBoxSizer *WxBoxSizer1;
 		wxPanel *FilesWxNoteBookPage;
+		wxListCtrl *InfoDownWxListCtrl;
+		wxBoxSizer *WxBoxSizer17;
+		wxPanel *WxPanel24;
 		wxListCtrl *InfoWxListCtrl;
 		wxGridSizer *WxGridSizer2;
+		wxPanel *WxPanel22;
+		wxSplitterWindow *WxSplitterWindow7;
+		wxButton *OnlineInfoWxButton;
 		wxButton *RestoreWxButton;
 		wxButton *BackupWxButton;
 		wxPanel *WxPanel16;
@@ -180,6 +221,30 @@ class PhoneFrm : public wxMDIChildFrame
 			ID_MNU_FORWARD_1095 = 1095,
 			ID_MNU_SENDNEWSMSTOSMSNUMBERS_1144 = 1144,
 			
+			ID_JAVADOWNWXLISTCTRL = 1214,
+			ID_WXPANEL27 = 1211,
+			ID_JAVAUPWXLISTCTRL = 1210,
+			ID_WXPANEL26 = 1208,
+			ID_WXSPLITTERWINDOW8 = 1207,
+			ID_JAVAGETWXBUTTON = 1215,
+			ID_WXPANEL25 = 1205,
+			ID_JAVAWXNOTEBOOKPAGE = 1203,
+			ID_TODODOWNWXLISTCTRL = 1184,
+			ID_WXPANEL23 = 1180,
+			ID_TODOUPWXLISTCTRL = 1183,
+			ID_WXPANEL21 = 1177,
+			ID_WXSPLITTERWINDOW6 = 1176,
+			ID_TODOGETWXBUTTON = 1173,
+			ID_WXPANEL20 = 1172,
+			ID_TODOWXNOTEBOOKPAGE = 1170,
+			ID_NOTESWXMEMO = 1169,
+			ID_WXPANEL19 = 1165,
+			ID_NOTESWXLISTCTRL = 1167,
+			ID_WXPANEL18 = 1163,
+			ID_WXSPLITTERWINDOW5 = 1156,
+			ID_NOTESGETWXBUTTON = 1154,
+			ID_WXPANEL17 = 1153,
+			ID_NOTESWXNOTEBOOKPAGE = 1150,
 			ID_CALENDARDOWNWXLISTCTRL = 1127,
 			ID_WXPANEL15 = 1119,
 			ID_CALENDARUPWXLISTCTRL2 = 1126,
@@ -243,12 +308,16 @@ class PhoneFrm : public wxMDIChildFrame
 			ID_WXPANEL2 = 1021,
 			ID_PHONEBOOKWXNOTEBOOKPAGE = 1018,
 			ID_FILESWXLISTCTRL = 1016,
-			ID_JAVAWXBUTTON = 1149,
 			ID_ADDFILEWXBUTTON = 1148,
 			ID_FILESGETWXBUTTON = 1017,
 			ID_WXPANEL1 = 1015,
 			ID_FILESWXNOTEBOOKPAGE = 1006,
-			ID_INFOWXLISTCTRL = 1137,
+			ID_INFODOWNWXLISTCTRL = 1201,
+			ID_WXPANEL24 = 1199,
+			ID_INFOWXLISTCTRL = 1196,
+			ID_WXPANEL22 = 1194,
+			ID_WXSPLITTERWINDOW7 = 1190,
+			ID_ONLINEINFOWXBUTTON = 1202,
 			ID_RESTOREWXBUTTON = 1147,
 			ID_BACKUPWXBUTTON = 1146,
 			ID_WXPANEL16 = 1134,
@@ -301,11 +370,18 @@ class PhoneFrm : public wxMDIChildFrame
 		void BackupWxButtonClick(wxCommandEvent& event);
 		void RestoreWxButtonClick(wxCommandEvent& event);
 		void AddFileWxButtonClick(wxCommandEvent& event);
+		void NotesGetWxButtonClick(wxCommandEvent& event);
+		void ToDoGetWxButtonClick(wxCommandEvent& event);
+		void NotesWxListCtrlSelected(wxListEvent& event);
+		void ToDoWxListCtrlSelected(wxListEvent& event);
+		void JavaWxButtonClick(wxCommandEvent& event);
+		void OnlineInfoWxButtonClick(wxCommandEvent& event);
+		void JavaGetWxButtonClick(wxCommandEvent& event);
         
 	private:
         BOOLEAN                             Phone;
 		MainFrm                             *parent;
-        wchart                              StatusStr[10], StatusStr2[10];
+        wchart                              StatusStr[15], StatusStr2[15];
 
         //files
         wchar_t                             FileFolderID[500], FileFolderID0[500];
@@ -359,6 +435,17 @@ class PhoneFrm : public wxMDIChildFrame
         void DisplayCalendar();
         BOOLEAN CheckCalendar();        
         void ReadCalendar();        
+        void RestoreCalendar();
+        
+        void DisplayNotes();   
+        void RestoreNotes();
+        BOOLEAN CheckNotes();
+        void ReadNotes();
+                
+        void RestoreToDo();
+        void PhoneFrm::DisplayToDo();
+        BOOLEAN CheckToDo();        
+        void ReadToDo();
 };
 
 #endif
